svgen.generation package — docs

Skip to main content
`Ctrl`+`K`

# svgen.generation package

## Submodules

## svgen.generation.images module

A module for generating images from SVG files.

svgen.generation.images.generate_icon(output_dir: Path) → None

  Generate an icon from previously generated PNG outputs.

svgen.generation.images.generate_images(doc: Svg, output: Path, cli_entry: str = 'inkscape') → bool

  Generate image outputs for this document.

## Module contents